Learn R Programming

WindCurves (version 0.2)

fitcurve: A fitcurve function

Description

Fits the power curve with Weibull CDF, Logistic and user defined techniques

Usage

fitcurve(data, MethodPath, MethodName)

Arguments

data

as input data.frame with two columns, i.e., wind speed and wind power

MethodPath

as path of a code for user defined curve fitting technique

MethodName

as name of the user defined curve fitting technique

Value

fitted curves and corresponding discrete fitted values

Examples

Run this code
# NOT RUN {
data(pcurves)
s <- pcurves$Speed
p <- pcurves$`Nordex N90`
da <- data.frame(s,p)
fitcurve(da)
# }

Run the code above in your browser using DataLab