powered by
Fits the power curve with Weibull CDF, Logistic and user defined techniques
fitcurve(data, MethodPath, MethodName)
as input data.frame with two columns, i.e., wind speed and wind power
as path of a code for user defined curve fitting technique
as name of the user defined curve fitting technique
fitted curves and corresponding discrete fitted values
# NOT RUN { data(pcurves) s <- pcurves$Speed p <- pcurves$`Nordex N90` da <- data.frame(s,p) fitcurve(da) # }
Run the code above in your browser using DataLab